==> tuia-advert-center-api-2.3.78-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertSdkDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import cn.com.duiba.tuia.core.api.dto.BaseDto;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author Wangpf
 * @description
 * @date 2019/8/30 3:19 PM
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class AdvertSdkDto extends BaseDto {

    private static final long serialVersionUID = -1296355125114379963L;

    public static final Integer CONFIG_TYPE_DEF = 0;
    public static final Integer CONFIG_TYPE_DL = 1;
    public static final Integer CONFIG_TYPE_JF = 2;


    /** 自动更新模式*/
    public static final Integer AUTO = 0;
    /** 人工更新模式*/
    public static final Integer PEOPLE = 1;

    /**
     * 广告id
     */
    private Long advertId;

    /**
     * 应用名
     */
    private String applicationName;

    /**
     * 包名
     */
    private String packageName;

    /**
     * 样式控制
     */
    private Integer styleControl;

    /**
     * 应用图标链接
     */
    private String appIconUri;

    /**
     * 头部标题
     */
    private String title;

    /**
     * 应用描述
     */
    private String applicationDesc;

    /**
     * 配置类型
     */
    private Integer configType;

    /**
     * 微信弹窗标题
     */
    private String windowTitle;

    /**
     * 微信弹窗描述
     */
    private String windowDesc;

    /**
     * 微信弹窗Toast文案
     */
    private String toastDesc;

    /**
     * 微信ID
     */
    private String wechatId;

    /**
     * 微信名称
     */
    private String wechatName;

    /**
     * 微信头像
     */
    private String wechatPic;

    /**
     * 微信号更新模式
     */
    private Integer updMode;

    /**
     * 推广目的 0 非应用下载 1 应用下载
     */
    private Integer expandTarget;
}

==> tuia-advert-center-api-2.5.21-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertSdkDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import cn.com.duiba.tuia.core.api.dto.BaseDto;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author Wangpf
 * @description
 * @date 2019/8/30 3:19 PM
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class AdvertSdkDto extends BaseDto {

    private static final long serialVersionUID = -1296355125114379963L;

    public static final Integer CONFIG_TYPE_DEF = 0;
    public static final Integer CONFIG_TYPE_DL = 1;
    public static final Integer CONFIG_TYPE_JF = 2;


    /** 自动更新模式*/
    public static final Integer AUTO = 0;
    /** 人工更新模式*/
    public static final Integer PEOPLE = 1;

    /**
     * 广告id
     */
    private Long advertId;

    /**
     * 应用名
     */
    private String applicationName;

    /**
     * 包名
     */
    private String packageName;

    /**
     * 样式控制
     */
    private Integer styleControl;

    /**
     * 应用图标链接
     */
    private String appIconUri;

    /**
     * 头部标题
     */
    private String title;

    /**
     * 应用描述
     */
    private String applicationDesc;

    /**
     * 配置类型
     */
    private Integer configType;

    /**
     * 微信弹窗标题
     */
    private String windowTitle;

    /**
     * 微信弹窗描述
     */
    private String windowDesc;

    /**
     * 微信弹窗Toast文案
     */
    private String toastDesc;

    /**
     * 微信ID
     */
    private String wechatId;

    /**
     * 微信名称
     */
    private String wechatName;

    /**
     * 微信头像
     */
    private String wechatPic;

    /**
     * 微信号更新模式
     */
    private Integer updMode;

    /**
     * 推广目的 0 非应用下载 1 应用下载
     */
    private Integer expandTarget;

    /** 应用推广图 */
    private String appProUrls;



    /**
     * 应用信息需求-应用名称
     */
    private String appInfoName;
    /**
     * 应用信息需求-应用版本
     */
    private String appInfoVersion;
    /**
     * '应用信息需求-应用开发者
     */
    private String appInfoDeveloper;
    /**
     * 应用信息需求-应用的包体大小
     */
    private String appInfoPkgSize;
    /**
     * 应用信息需求-应用权限H5链接
     */
    private String appInfoPermissionUrl;
    /**
     * 应用信息需求-应用隐私政策H5链接
     */
    private String appInfoPrivacyUrl;
}
